<?php

namespace Modules\Cotacao\Modules\Pedido\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class Sup09400DadosDoFornecedorEcommerceController extends \Teknisa\GER\Controllers\TeknisaCrud
{
    protected $service;
    protected $serviceEmail;
    protected $fileServerURL;

    public function __construct($service, $serviceEmail, $fileServerURL)
    {
        $this->service           = $service;
        $this->serviceEmail      = $serviceEmail;
        $this->fileServerURL     = $fileServerURL;
    }

    public function chkAceite(DTO\Request $request, DTO\Response $response)
    {
        try {
            $dataSet = $this->service->getTermoAceite();

            $response->addDataSet(new DataSet('termoAceite', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function filter(DTO\Request $request, DTO\Response $response)
    {
        try {
            $request->getFilterCriteria();

            $conditions = $request->getFilterCriteria()->getConditions();
            $cdfilial = $conditions[0]['value'];
            $dataSet['PARAMETROS_GERAIS'] = $this->service->getParametrosGerais($cdfilial);
            $dataSet['IDSISDOS'] = $this->service->retornaParamgeral()['IDSISDOS'];

            $logo = $this->service->getLogoEmail();
            $dataSet['PARAMETROS_GERAIS'][0]['LOGO_UPLOAD'] = $logo["URLLOGO"] == null ? null : $this->fileServerURL . $logo["URLLOGO"];
            $response->addDataSet(new DataSet('paramgeralecommerce', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function saveParamGeral(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            $centralCompras = $this->service->retornaCentralCompras($row);
            $this->service->saveDNS($row["DSLINKECOMMERCE"]);

            if (isset($row["UPDATESMTP"])) {
                $result = $this->service->updateUnidadePadraoSMTP($row);
            }

            $result = $this->service->saveParametrosGerais($row, $centralCompras);

            if ($result !== 0) {
                $dataSet = $this->service->getParametrosGerais($row['CDFILIAL']);
            } else {
                $dataSet = array();
            }

            $response->addDataSet(new DataSet('paramgeralecommerce', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function uploadLogo(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            $logo = isset($row["LOGO_UPLOAD"][0]["path"]) ? $row["LOGO_UPLOAD"][0]["path"] : null;

            if ($logo == null) {
                $this->service->saveLogoEmail($logo);
                $return = $this->createReturnArray(false, "LOGO_REMOVED_SUCCESS");
                $return["LOGO"] = null;
            } else {
                if (!$this->checkExtension($logo)) {
                    $return = $this->createReturnArray(true, "FILE_EXTENSION_PROBLEM");
                    $return["LOGO"] = null;
                } else {
                    $this->service->saveLogoEmail($logo);
                    $return = $this->createReturnArray(false, "LOGO_UPDATED_SUCCESS");
                    $logoPath = $this->fileServerURL . $logo;
                    $return["LOGO"] = $logoPath;
                }
            }
        } catch (\Exception $e) {
            $return = $this->createReturnArray(true, "ERRO_DURANTE_OPERACAO");
            $return["LOGO"] = null;
        } finally {
            $response->addDataSet(new DataSet('response', $return));
        }
    }

    private function createReturnArray($status, $message)
    {
        return array(
            "ERROR" => $status,
            "MESSAGE" => $message
        );
    }

    private function manageLogoEmail($row)
    {
        $logo = isset($row["LOGO_UPLOAD"][0]["path"]) ? $row["LOGO_UPLOAD"][0]["path"] : null;

        if ($logo == null || $this->checkExtension($logo)) {
            $this->service->saveLogoEmail($logo);
        }
    }

    private function checkExtension($path)
    {
        $info = pathinfo($path);

        $extensions = array("jpg", "JPG", "jpeg", "JPEG", "png", "PNG");

        return in_array($info["extension"], $extensions) ? true : false;
    }

    public function checkTermCanTurnOff(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();

        $result = $this->service->checkActiveCollectRequest($row["CDFORNECED"]);

        if (isset($result[0]["NRPEDIDOCOL"])) {
            $return = $this->createReturnArray(true, "CANT_TURNOFF_TERM");
        } else {
            $return = $this->createReturnArray(false, "CAN_TURNOFF_TERM");
        }

        $response->addDataSet(new DataSet('response', $return));
    }

    public function cronJobNotificacoesAF(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $dataSet = $this->service->getAFsNaoLidas($row);
            $arrayEmails = $this->formataArrayCronJob($dataSet, 'AF');
            $this->serviceEmail->enviaEmailAFCronJob($arrayEmails, $row);
            $response->addDataSet(new DataSet('notificacoesecommerce', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function cronJobNotificacoesPC(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $dataSet = $this->service->getPCsNaoLidas($row);
            $arrayEmails = $this->formataArrayCronJob($dataSet, 'PC');
            $this->serviceEmail->enviaEmailPCCronJob($arrayEmails, $row);
            $response->addDataSet(new DataSet('notificacoesecommerce', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function formataArrayCronJob($arrayDataSet, $cronJob)
    {
        if (!empty($arrayDataSet)) {
            $newArray = [];

            switch ($cronJob) {
                case 'AF':
                    foreach ($arrayDataSet as $i => $dataSet) {
                        $newArray[$dataSet['NMRAZSOCFORN']][$dataSet['DTENTREGAFFORN']][$dataSet['NMFILIAL']][$i] = $dataSet;
                    }
                    break;

                case 'PC':
                    foreach ($arrayDataSet as $i => $dataSet) {
                        $newArray[$dataSet['NMRAZSOCFORN']][$dataSet['DTEXPIRAPEDCOL']][$i] = $dataSet;
                    }
                    break;
            }

            return $newArray;
        }

        return false;
    }

    public function notificacoesEcommerce(DTO\Request $request, DTO\Response $response)
    {
        try {
            $request->getFilterCriteria();
            $conditions = $request->getFilterCriteria()->getConditions();
            $row['NRORG'] =  $conditions[0]['value'];
            $row['CDFILIAL'] = $conditions[1]['value'];
            $dataSet = $this->service->getDadosNotificacao($row);
            $response->addDataSet(new DataSet('notificacoesecommerce', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function saveNotificacoesEcommerce(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            $result = $this->service->saveNotificacoesEcommerce($row);

            if ($result !== 0) {
                $dataSet = $this->service->getDadosNotificacao($row);
            } else {
                $dataSet = array();
            }

            $response->addDataSet(new DataSet('notificacoesecommerce', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function deleteNotificacoesEcommerce(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            $result = $this->service->deleteNotificacoesEcommerce($row);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function filterPedidoColeta(DTO\Request $request, DTO\Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $cdforneced = $conditions[0]['value'];
            $dataSet = $this->service->getPedidoColeta($cdforneced);
            $response->addDataSet(new DataSet('fornecedor_operador', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function savePedidoColeta(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $result = $this->service->savePedidoColeta($row);

            if ($result !== 0) {
                $dataSet = $this->service->getPedidoColeta($row["CDFORNECED"]);
            } else {
                $dataSet = array();
            }

            $response->addDataSet(new DataSet('fornecedor_operador', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    // ACESSO AO PORTAL 
    public function deleteLoginAcesso(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $this->service->beginTransaction();

            $rows = (array) $request->getRow();

            foreach ($rows as $row) {
                $result = $this->service->deleteLoginAcesso($row);
            }
            /*$data = $this->service->verificaExclusao(end($rows));

            if (is_array($data) && count($data)) {
                $this->service->deletaInfoOperador(end($row));
            }*/

            $this->service->commit();
        } catch (\Exception $e) {
            $this->service->rollback();
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
            return false;
        }

        $this->serviceEmail->enviarEmail(end($row), $response);
    }

    public function validacoesAcesso(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $fornecedoresRelacionados = $this->service->validacoesAcesso($request, $response);
            $response->addDataSet(new DataSet('fornecedoresRelacionados', $fornecedoresRelacionados));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function saveLoginRelacionado(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $fornecedoresRelacionados = $this->service->saveLoginRelacionado($row);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function saveNovoLogin(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            $operadorSistemaTeknisa = $this->service->saveNovoLogin($row);

            $this->serviceEmail->enviarEmail($row, $response);

            $response->addMessage(new DTO\Response\Message(array('OPERADOR_SISTEMA_TEKNISA' => $operadorSistemaTeknisa)));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function saveEdicaoLogin(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $operadorSistemaTeknisa = $this->service->saveEdicaoLogin($row);
            $response->addMessage(new DTO\Response\Message(array('OPERADOR_SISTEMA_TEKNISA' => $operadorSistemaTeknisa)));
            $this->serviceEmail->enviarEmail($row, $response);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function uploadManual(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $row["DSMANUALFILESERV"] = isset($row["MANUAL"]) && sizeof($row["MANUAL"]) ? $row["MANUAL"][0]["path"] : ' ';
            $this->service->uploadManual($row);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function getManualInfo(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $result = $this->service->getManualInfo($row);
            $uri = "";
            $ext = "";

            if ($result === false) {
                $uri = false;
                $ext = false;
            } else if ($result != "") {
                $uri = $this->fileServerURL . $result;
                $ext = pathinfo($result, PATHINFO_EXTENSION);
            }

            $return = [
                "uri" => $uri,
                "ext" => $ext
            ];

            $response->addDataSet(new DataSet('file', $return));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function downloadManual(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getDataSet()->getRows()[0];
        $file = $row["path"];
        $name = $row["name"];
        $nameArray = explode(".", $name);
        $type = end($nameArray);

        header('Accept-Ranges: none');
        header("Content-Type: " . $type);
        header("Content-Disposition: attachment; filename=" . $name);
        readfile($file);
        exit;
    }

    public function gerarChaveAcesso(DTO\Request $request, DTO\Response $response)
    {
        try {
            $fornecedor = $request->getRow();

            $fornecedor = $fornecedor['fornecedor'];
            $chave = md5(uniqid("TEKNISA", true));

            $this->service->salvaChaveAcesso($fornecedor, $chave);

            $response->addMessage(new DTO\Response\Message($chave));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function retornaUnidadePadraoSMTP(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $unidedePadraoSMTP = $this->service->retornaUnidadePadraoSMTP();
            $dataset = array(
                "CDFILIAL"   => $unidedePadraoSMTP
            );
            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}
